YurApi class

Constructors

YurApi()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

IP() Future<Map<String, dynamic>>
Nominatim({required String lat, required String lon}) Future<Map<String, dynamic>>
Respon({required String urlHttp, required Map<String, dynamic> dataMap, bool isEncoded = false, bool isGet = false, Map<String, String> headers = const {'content-type' : 'application/json'}}) Future<Map<String, dynamic>>