NominatimModel class

Constructors

NominatimModel({int? placeId = 0, String? licence = '', String? osmType = '', int? osmId = 0, String? lat = "0.0", String? lon = "0.0", String? category = '', String? type = '', int? placeRank = 0, double? importance = 0.0, String? addressType = '', String? name = '', String? displayName = '', AddressNominatim address = const AddressNominatim(), List boundingBox = const []})
NominatimModel.fromJson(Map<String, dynamic> json)
factory

Properties

address AddressNominatim
final
addressType String?
final
boundingBox List
final
category String?
final
displayName String?
final
hashCode int
The hash code for this object.
no setterinherited
importance double?
final
lat String?
final
licence String?
final
lon String?
final
name String?
final
osmId int?
final
osmType String?
final
placeId int?
final
placeRank int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited