Get class

Constructors

Get()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

context → dynamic
no setter
height double
no setter
getter/setter pair
width double
no setter

Static Methods

back({dynamic result}) → void
close() → void
firstRoute() Future
launch({required String url, required UrlScheme urlScheme}) Future<void>
offAll(Widget page, {BuildContext? localContext}) Future
replace(Widget page, {BuildContext? localContext}) Future
to(Widget page, {BuildContext? localContext}) Future